color

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 4, 2018 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

const (
	FgBlack  = 0
	FgRed    = 1
	FgGreen  = 2
	FgYellow = 3
	FgBlue   = 4
	FgPurple = 5
)
const (
	Regular   = 1
	Light     = 2
	Highlight = 3
	Underline = 4
)

Variables

This section is empty.

Functions

func Black

func Black(style int, format string, a ...interface{}) string

Black is a convenient helper function to return a string with black foreground

func Blue

func Blue(style int, format string, a ...interface{}) string

Blue is a convenient helper function to return a string with blue foreground

func Green

func Green(style int, format string, a ...interface{}) string

Green is a convenient helper function to return a string with green foreground

func Purple

func Purple(style int, format string, a ...interface{}) string

Purple is a convenient helper function to return a string with purple foreground

func Red

func Red(style int, format string, a ...interface{}) string

Red is a convenient helper function to return a string with red foreground

func Yellow

func Yellow(style int, format string, a ...interface{}) string

Yellow is a convenient helper function to return a string with yellow foreground

Types

This section is empty.

Jump to