Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var All = []Conflict{}
var Count int
var FileLines map[string][]string
Functions ¶
func RunCommand ¶
func RunCommand(name string, dir string, args ...string) (stdout string, stderr string, exitCode int)
RunCommand runs the given command with arguemtns and returns the output Refer to https://stackoverflow.com/questions/10385551/get-exit-code-go
Types ¶
type Conflict ¶
type Conflict struct {
Choice int
FileName string
AbsolutePath string
Start int
Middle int
End int
LocalLines []string
IncomingLines []string
ColoredLocalLines []string
ColoredIncomingLines []string
CurrentName string
ForeignName string
TopPeek int
BottomPeek int
DisplayDiff bool
}
Conflict represents a single conflict that may have occured
func (*Conflict) ExtractLines ¶
func (*Conflict) PaddingLines ¶
func (*Conflict) SyntaxHighlight ¶
func (*Conflict) ToggleDiff ¶
func (c *Conflict) ToggleDiff()
type ErrNoConflict ¶
type ErrNoConflict struct {
// contains filtered or unexported fields
}
func NewErrNoConflict ¶
func NewErrNoConflict(message string) *ErrNoConflict
func (*ErrNoConflict) Error ¶
func (e *ErrNoConflict) Error() string
Click to show internal directories.
Click to hide internal directories.